import { useEffect, useRef, useState } from "preact/hooks";
import { DateTime } from "luxon";
import { useTimezone } from "../App/TimezoneProvider";

export const TimeInput = ({ defaultValue, onInput }) => {
    const format = "yyyy-LL-dd, HH:mm:ss";
    const ref = useRef(null);

    const [zone] = useTimezone();
    const [time, setTime] = useState(defaultValue);

    useEffect(() => {
        onInput(time);
    }, [time]);

    return (
        <>
            <div class={"input"}>
                <input
                    placeholder={"YYYY-MM-DD, hh:mm:ss"}
                    style={{
                        border: "none",
                        fontSize: "16px",
                    }}
                    value={time && time.toFormat(format)}
                    onInput={(ev) => {
                        const dt = DateTime.fromFormat(ev.currentTarget.value, format);
                        if (dt.isValid) {
                            setTime(dt);
                        }
                    }}
                ></input>
                <button
                    style={{
                        background: "none",
                        border: "none",
                        padding: "1px",
                        marginRight: "-3px",
                    }}
                    onClick={() => {
                        ref.current.showPicker();
                    }}
                >
                    <span class="is-sr-only">Clear interval</span>
                    <span class="icon">
                        <i class="fas fa-calendar"></i>
                    </span>
                </button>
            </div>
            <input
                style={{
                    visibility: "hidden",
                }}
                type="datetime-local"
                step="1"
                name="time"
                value={time && time.toFormat("yyyy-LL-dd'T'HH:mm:ss")}
                ref={ref}
                onInput={(ev) => {
                    setTime(DateTime.fromISO(ev.currentTarget.value));
                }}
            ></input>
        </>
    );
};
